@@ -10,6 +10,20 @@
 //!
 //! <https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations-metrics.html>
 
+mod avg_aggregation;
+mod boxplot_aggregation;
+mod cardinality_aggregation;
+mod max_aggregation;
+mod min_aggregation;
+mod rate_aggregation;
+mod sum_aggregation;
 mod top_hits_aggregation;
 
+pub use self::avg_aggregation::*;
+pub use self::boxplot_aggregation::*;
+pub use self::cardinality_aggregation::*;
+pub use self::max_aggregation::*;
+pub use self::min_aggregation::*;
+pub use self::rate_aggregation::*;
+pub use self::sum_aggregation::*;
 pub use self::top_hits_aggregation::*;
