@@ -35,13 +35,13 @@ pub struct BoolQuery {
 #[derive(Debug, Clone, PartialEq, Serialize, Default)]
 struct Inner {
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
-    must: Vec<Query>,
+    must: Queries,
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
-    filter: Vec<Query>,
+    filter: Queries,
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
-    should: Vec<Query>,
+    should: Queries,
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
-    must_not: Vec<Query>,
+    must_not: Queries,
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
     minimum_should_match: Option<MinimumShouldMatch>,
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
@@ -59,58 +59,20 @@ impl Query {
 
 impl BoolQuery {
     /// The clause (query) must appear in matching documents and will contribute to the score.
-    pub fn must(mut self, query: impl Into<Option<Query>>) -> Self {
-        let query = query.into();
-
-        if let Some(query) = query {
-            if !query.should_skip() {
-                self.inner.must.push(query);
-            }
-        }
-
-        self
-    }
-
-    /// The clause (query) must appear in matching documents and will contribute to the score.
-    pub fn musts<I>(mut self, queries: I) -> Self
+    pub fn must<Q>(mut self, queries: Q) -> Self
     where
-        I: IntoIterator,
-        I::Item: Into<Query>,
+        Q: Into<Queries>,
     {
-        for query in queries.into_iter().map(Into::into) {
-            if !query.should_skip() {
-                self.inner.must.push(query);
-            }
-        }
-
+        self.inner.must.extend(queries);
         self
     }
 
     /// The clause (query) should appear in the matching document.
-    pub fn should(mut self, query: impl Into<Option<Query>>) -> Self {
-        let query = query.into();
-
-        if let Some(query) = query {
-            if !query.should_skip() {
-                self.inner.should.push(query);
-            }
-        }
-
-        self
-    }
-
-    /// The clause (query) should appear in the matching document.
-    pub fn shoulds<I>(mut self, queries: I) -> Self
+    pub fn should<Q>(mut self, queries: Q) -> Self
     where
-        I: IntoIterator,
-        I::Item: Into<Query>,
+        Q: Into<Queries>,
     {
-        for query in queries.into_iter().map(Into::into) {
-            if !query.should_skip() {
-                self.inner.should.push(query);
-            }
-        }
-
+        self.inner.should.extend(queries);
         self
     }
 
@@ -118,33 +80,11 @@ impl BoolQuery {
     /// However unlike must the score of the query will be ignored.
     /// Filter clauses are executed in [filter context](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-filter-context.html),
     /// meaning that scoring is ignored and clauses are considered for caching.
-    pub fn filter(mut self, query: impl Into<Option<Query>>) -> Self {
-        let query = query.into();
-
-        if let Some(query) = query {
-            if !query.should_skip() {
-                self.inner.filter.push(query);
-            }
-        }
-
-        self
-    }
-
-    /// The clause (query) must appear in matching documents.
-    /// However unlike must the score of the query will be ignored.
-    /// Filter clauses are executed in [filter context](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-filter-context.html),
-    /// meaning that scoring is ignored and clauses are considered for caching.
-    pub fn filters<I>(mut self, queries: I) -> Self
+    pub fn filter<Q>(mut self, queries: Q) -> Self
     where
-        I: IntoIterator,
-        I::Item: Into<Query>,
+        Q: Into<Queries>,
     {
-        for query in queries.into_iter().map(Into::into) {
-            if !query.should_skip() {
-                self.inner.filter.push(query);
-            }
-        }
-
+        self.inner.filter.extend(queries);
         self
     }
 
@@ -152,33 +92,11 @@ impl BoolQuery {
     /// Clauses are executed in [filter context](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-filter-context.html)
     /// meaning that scoring is ignored and clauses are considered for caching.
     /// Because scoring is ignored, a score of `0` for all documents is returned.
-    pub fn must_not(mut self, query: impl Into<Option<Query>>) -> Self {
-        let query = query.into();
-
-        if let Some(query) = query {
-            if !query.should_skip() {
-                self.inner.must_not.push(query);
-            }
-        }
-
-        self
-    }
-
-    /// The clause (query) must not appear in the matching documents.
-    /// Clauses are executed in [filter context](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-filter-context.html)
-    /// meaning that scoring is ignored and clauses are considered for caching.
-    /// Because scoring is ignored, a score of `0` for all documents is returned.
-    pub fn must_nots<I>(mut self, queries: I) -> Self
+    pub fn must_not<Q>(mut self, queries: Q) -> Self
     where
-        I: IntoIterator,
-        I::Item: Into<Query>,
+        Q: Into<Queries>,
     {
-        for query in queries.into_iter().map(Into::into) {
-            if !query.should_skip() {
-                self.inner.must_not.push(query);
-            }
-        }
-
+        self.inner.must_not.extend(queries);
         self
     }
 
@@ -191,7 +109,10 @@ impl BoolQuery {
     ///
     /// For other valid values, see the
     /// [minimum_should_match parameter](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-minimum-should-match.html).
-    pub fn minimum_should_match(mut self, minimum_should_match: impl Into<String>) -> Self {
+    pub fn minimum_should_match<S>(mut self, minimum_should_match: S) -> Self
+    where
+        S: Into<MinimumShouldMatch>,
+    {
         self.inner.minimum_should_match = Some(minimum_should_match.into());
         self
     }
@@ -212,15 +133,16 @@ impl ShouldSkip for BoolQuery {
 mod tests {
     use super::*;
 
-    test_serialization! {
-        with_required_fields(Query::bool(), json!({ "bool": {} }));
+    #[test]
+    fn serialization() {
+        assert_serialize(Query::bool(), json!({ "bool": {} }));
 
-        with_multiple_queries(
+        assert_serialize(
             Query::bool()
-                .musts([Query::term("test1", 1), Query::term("test2", 2)])
-                .shoulds([Query::term("test1", 3), Query::term("test2", 4)])
-                .filters([Query::term("test1", 5), Query::term("test2", 6)])
-                .must_nots([Query::term("test1", 7), Query::term("test2", 8)])
+                .must([Query::term("test1", 1), Query::term("test2", 2)])
+                .should([Query::term("test1", 3), Query::term("test2", 4)])
+                .filter([Query::term("test1", 5), Query::term("test2", 6)])
+                .must_not([Query::term("test1", 7), Query::term("test2", 8)])
                 .minimum_should_match("2")
                 .boost(1.3)
                 .name("test"),
@@ -246,10 +168,10 @@ mod tests {
                     "boost": 1.3,
                     "_name":"test"
                 }
-            })
+            }),
         );
 
-        with_all_fields(
+        assert_serialize(
             Query::bool()
                 .must(Query::term("test1", 1))
                 .must(Query::term("test2", 2))
@@ -284,7 +206,7 @@ mod tests {
                     "boost": 1.3,
                     "_name":"test"
                 }
-            })
+            }),
         );
     }
 }
