@@ -6,6 +6,7 @@ mod percolate_lookup_query;
 mod percolate_query;
 mod pinned_query;
 mod rank_feature_query;
+mod wrapper_query;
 
 pub use self::distance_feature_query::*;
 pub use self::more_like_this_query::*;
@@ -13,3 +14,4 @@ pub use self::percolate_lookup_query::*;
 pub use self::percolate_query::*;
 pub use self::pinned_query::*;
 pub use self::rank_feature_query::*;
+pub use self::wrapper_query::*;
